#
# spec file for package lmms
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The revision numbers for rpmalloc and qt5-x11embed come from accessing them via
# https://github.com/LMMS/lmms/tree/v%%{version}/src/3rdparty/qt5-x11embed and
# https://github.com/LMMS/lmms/tree/v1.2.1/src/3rdparty/rpmalloc/rpmalloc (two directories not a mistake)
%define rpmallocrev b5bdc18051bb74a22f0bde4bcc90b01cf590b496
%define qt5x11embedrev 022b39a1d496d72eb3e5b5188e5559f66afca957
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
%bcond_with  wine
%endif
%bcond_without  carla
%bcond_without  crippled_stk
Name:           lmms
Version:        1.2.2
Release:        13.16
Summary:        Linux MultiMedia Studio
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            https://lmms.io/
Source0:        https://github.com/LMMS/lmms/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/mjansson/rpmalloc/archive/%{rpmallocrev}.tar.gz
Source2:        https://github.com/lukas-w/qt5-x11embed/archive/%{qt5x11embedrev}.tar.gz
%if %{with wine}
Source3:        lmms-warning
%endif
# PATCH-FIX-OPENSUSE Patch for providing proper return code in a function
Patch0:         lmms-1.2.0-return.patch
%if %{with crippled_stk}
# PATCH-FIX-OPENSUSE Some parts cannot be build because stk misses some files due to legal issues (bnc#761147)
Patch1:         lmms-1.2.0-crippled_stk.patch
%endif
# PATCH-FIX-UPSTREAM Fix plugin library search path, testing an upstream proposal
Patch2:         lmms-1.2.0-libdir.patch
Patch3:         lmms-rpmalloc-fpic.patch
# PATCH-FIX-UPSTREAM -- Fix build with recent carla releases
Patch4:         lmms-1.2.2-carla_defines.patch
BuildRequires:  bash-completion
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  filesystem
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libstk-devel
BuildRequires:  pkgconfig
BuildRequires:  sndio-devel
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3f) >= 3.0.0
BuildRequires:  pkgconfig(fluidsynth) >= 1.0.7
BuildRequires:  pkgconfig(gig)
BuildRequires:  pkgconfig(jack) >= 0.77
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(libmp3lame)
%else
BuildRequires:  libmp3lame-devel
%endif
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(portaudiocpp)
BuildRequires:  pkgconfig(samplerate) >= 0.1.8
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(sndfile) >= 1.0.11
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-util)
# SECTION Zynaddsubfx
BuildRequires:  fltk-devel
BuildRequires:  pkgconfig(mxml)
BuildRequires:  pkgconfig(ntk)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
# /SECTION
%if %{with carla}
# also needed (contains libcarla_standalone2 library)
# to enable internal Carla plugin host
BuildRequires:  carla
BuildRequires:  pkgconfig(carla-native-plugin)
%requires_eq    carla
%endif
%if %{with wine}
#Extra packages
BuildRequires:  gcc-c++-32bit
BuildRequires:  libstdc++-devel-32bit
BuildRequires:  wine
BuildRequires:  wine-32bit
BuildRequires:  wine-devel
BuildRequires:  wine-devel-32bit
#!BuildIgnore:  sane-backends-32bit
%endif
ExclusiveArch:  x86_64

%description
LMMS is a free cross-platform music studio which allows you to produce music
with your computer. This includes the creation of melodies and beats, the
synthesis and mixing of sounds, and arranging of samples.
%if %{with wine}
You need to install lmms-vst for VST plugins

%package vst
Summary:        Wine dependent VST plugins
Group:          Productivity/Multimedia/Sound/Midi
Requires:       %{name} = %{version}
Requires:       wine
Obsoletes:      %{name} < 1.2.1

%description vst
LMMS is a free cross-platform music studio which allows you to produce music
with your computer. This includes the creation of melodies and beats, the
synthesis and mixing of sounds, and arranging of samples.
This package contains the wine dependent VST plugins
%endif

%package devel
Summary:        Headers to create LMMS plugins
Group:          Development/Libraries/C and C++

%description devel
Headers that provide access to the LMMS features. Install it if you plan to
create a LMMS plugin.

%prep
%autosetup -p1

pushd src/3rdparty
rm -r qt5-x11embed
tar -xf %{SOURCE2} && mv qt5-x11embed-%{qt5x11embedrev} qt5-x11embed
pushd qt5-x11embed
rm -r 3rdparty/ECM
ln -s %{_datadir}/ECM 3rdparty/ECM
popd
cd rpmalloc && rm -r rpmalloc && tar -xf %{SOURCE1} && mv rpmalloc-%{rpmallocrev} rpmalloc
popd

%build
export PATHBU=$PATH
%if %{with wine}
# Remove -m64 from CFLAGS, it causes VST build failure.
export CFLAGS="-O2 -g -fmessage-length=0 -D_FORTIFY_SOURCE=2 -fstack-protector -funwind-tables -fasynchronous-unwind-tables"
%define optflags $CFLAGS
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
#Add workaround for boo#1179734 to create the missing libwine.so symlink
export WINELIB=$(find %{_libdir} -name libwine.so.?)
export WINELIB32=$(find %{_prefix}/lib -name libwine.so.?)
export WINELINK=$(echo $WINELIB | cut -d . -f 1,2)
if ! test -e ${WINELINK}
then
mkdir -p $HOME/%{_lib}/wine
mkdir -p $HOME/lib/wine
pushd $HOME/%{_lib}/wine
ln -sf ${WINELIB} libwine.so
cd ../../lib/wine
ln -sf ${WINELIB32} libwine.so
export PATH="$PATH:$HOME/%{_lib}/:$HOME/lib"
popd
fi
%endif
%endif

export CFLAGS="$CFLAGS -fPIC"

# https://docs.lmms.io/user-manual/getting-started/troubleshooting?q=midi+keyboards#i-compiled-lmms-with-vst-support-but-it-doesnt-work-at-all
export CFLAGS="$CFLAGS -fno-omit-frame-pointer"
export CXXFLAGS="%optflags -fno-omit-frame-pointer"

%cmake \
%if %{with wine}
  -DCMAKE_CXX_FLAGS:STRING="$CXXFLAGS -D__WIDL_objidl_generated_name_0000000C=""" \
%else
  -DWANT_VST_NOWINE:BOOL=ON \
%endif
  -DWANT_QT5=ON \
  -DCMAKE_SHARED_LINKER_FLAGS="" \
  -DCMAKE_EXE_LINKER_FLAGS:STRING="$LDFLAGS -pie" \
%if !%{with carla}
  -DWANT_CARLA:BOOL=OFF \
%endif
  -Wno-dev

export PATH=$PATHBU
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
sed -i 's/\/wine\/libwinecrt0.a//' plugins/vst_base/CMakeFiles/vstbase.dir/build.make
sed -i 's/libwinecrt0.a\/wine\///' plugins/vst_base/CMakeFiles/vstbase.dir/build.make
%endif

%cmake_build

%install
%cmake_install

mkdir -p '%{buildroot}%{_defaultdocdir}/lmms/'

# remove unneeded static helper library from install
rm %{buildroot}%{_libdir}/libqx11embedcontainer.a

# workaround: copy bash completion manually into install dir because it fails during cmake install
mkdir -p %{buildroot}/%{_datadir}/bash-completion/completions
cp %{_builddir}/lmms*/doc/bash-completion/lmms %{buildroot}%{_datadir}/bash-completion/completions/lmms

%fdupes -s %{buildroot}/%{_datadir}

%if %{with wine}
mkdir -p %{buildroot}%{_localstatedir}/adm/update-messages/
# Install lmms-warning
cp %{SOURCE3}  %{buildroot}%{_localstatedir}/adm/update-messages/
%endif

%files
%doc doc/AUTHORS README.md INSTALL.txt
%license LICENSE.txt
%{_bindir}/lmms
%{_mandir}/man1/lmms.1%{?ext_man}
%{_libdir}/lmms/
%{_datadir}/lmms/
%{_datadir}/applications/lmms.desktop
%{_datadir}/icons/hicolor/*
%{_datadir}/mime/packages/lmms.xml
%{_datadir}/bash-completion/completions/lmms

%if %{with wine}
%{_localstatedir}/adm/update-messages/%{name}-warning
%exclude %{_libdir}/lmms/RemoteVstPlugin
%exclude %{_libdir}/lmms/RemoteVstPlugin.exe.so
%exclude %{_libdir}/lmms/libvsteffect.so

%post
cat %{_localstatedir}/adm/update-messages/%{name}-warning

%files vst
%{_libdir}/lmms/RemoteVstPlugin
%{_libdir}/lmms/RemoteVstPlugin.exe.so
%{_libdir}/lmms/libvsteffect.so
%endif

%files devel
%defattr(0644,root,root,0755)
%{_includedir}/lmms/

%changelog
* Wed Mar 15 2023 Dave Plater <davejplater@gmail.com>
- Disable wine vst due to libwine.so.1 being removed in wine version
  8.3 see https://bugs.winehq.org/show_bug.cgi?id=54635 and
  https://github.com/LMMS/lmms/issues/6672
* Thu Dec 29 2022 Christophe Marin <christophe@krop.fr>
- Reenable the VST plugin integration.
* Sat Dec  3 2022 Dave Plater <davejplater@gmail.com>
- Disable vst until wine build issue is solved
* Tue Oct 25 2022 Max Lin <mlin@suse.com>
- Buildrequires libmp3lame-devel instead of pkgconfig(libmp3lame) on
  SLE15/Leap15
* Fri Oct 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add -fno-omit-frame-pointer to compiler flags as suggested
  in the lmms docs.
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Spec Cleanup
- Enable Carla integration again
- Remove unneeded build requirements
- Don't set CMAKE_SKIP_RPATH, disabling rpath completely breaks
  a couple plugins (carla, ZynAddSubFX, VeSTige...)
- Only skip Wine integration on Leap 15.3
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with recent carla version:
  * lmms-1.2.2-carla_defines.patch
* Wed May  4 2022 Dave Plater <davejplater@gmail.com>
- Disable building carla plugins, lmms no longer builds with the
  latest carla.
* Thu Apr 14 2022 Max Lin <mlin@suse.com>
- Create the missing libwine.so symlink for Leap 15.4
* Mon Dec  6 2021 Dave Plater <davejplater@gmail.com>
- Allow rpm to find all runtime dependancies by removing the line
  %%global __requires_exclude_from ^%%{_libdir}/lmms/.*\\.so$
  from the spec file. Reverses "Require libgig and libstk"
* Mon Nov  8 2021 Dave Plater <davejplater@gmail.com>
- Require libgig and libstk devel packages at runtime to fix
  boo#1192237
* Mon Nov  8 2021 Dave Plater <davejplater@gmail.com>
- Reenable VST build, issue boo#1192413 is fixed.
* Sat Nov  6 2021 Dave Plater <davejplater@gmail.com>
- Disable VST build until lmms issue boo#1192413 is fixed
* Tue May 25 2021 Dave Plater <davejplater@gmail.com>
- Fix workaround to find the correct libwine directory to fix
  Factory build.
* Sun Dec 20 2020 Dave Plater <davejplater@gmail.com>
- Add workaround for wine 6's lack of libwine.so symlink see:
  boo#1179734
* Sat Jul 18 2020 Dave Plater <davejplater@gmail.com>
- Update to version 1.2.2
- Remove incorporated qt5.15 with lmms-qpainterpath.patch
- Rebase lmms-1.2.0-crippled_stk.patch and lmms-rpmalloc-fpic.patch
- Upstream General improvements
  * Stop filtering out valid characters from file name while
  exporting tracks (#5282)
  * Fix Invalid warning about "dummy-MIDI-client" (#5509)
- Upstream UI improvements
  * Note selection: Editing values works in dialog (#5438)
- Upstream Bug Fixes
  * Piano Roll - Fix retrigger with vol/pan sliders (#5271)
  * Fix a rare crash on export (#5293)
  * Fix LMMS not launching when AppImage has spaces in name (#5297)
  * Fix vertical piano being unresponsive when clicked too fast
  (#5262)
  * Fix crash with Grooove VST (#5300)
  * Fix crash on deleting instrument with controller connections on
  knobs (#5306)
  * Fix notes being placed at negative positions on MIDI import
  (#5343)
  * Fix scrolling direction in the song editor due to stuck
  Ctrl/Shift (#5286)
  * Fix stuck notes with Helm VST on tempo automation (#5365)
  * Fix file factory delimeter position (#5378)
  * Fix controls linking misbehaviors (#5336)
  * Fix loading and saving of .fxb/.fxp files on Windows (#5411)
  * Fix crashes and hangs on importing some Hydrogen drum kit songs
  (#5420)
  * Fix freeze when replacing Mallets with another instrument
  (#5428)
  * DrumSynth: ensure correct envelope length in any sample rate
  (#5467)
  * AFP: fix loading start and loop points if the loop point is
  automated (#5472)
  * Select the correct piano key for marking semitones (#5478)
  * Ensure consistent use of effect gate (#5475)
  * Fix Piano roll crashing when window is vertically scaled too
  large (#5449)
  * Fix some memory errors with JACK audio/MIDI (#5452)
  * JackMidi: Remove confusing warnings at shutdown (737fcd3)
  * Fix SF2 player crashing when file is not a soundfont, with
  FluidSynth 2 (#5487)
  * BB editor: fix mouse event affecting wrong beats due to the
  cursor shape (#5489)
  * Fix knobs moving too fast on some platforms (#5360)
  * Fix notes created in BB editor resizing incorrectly when
  resizing a selection (#5515)
  * Fix some patterns not being saved in project (#5537)
* Fri Jun  5 2020 Dave Plater <davejplater@gmail.com>
- Fix build with qt5.15 with lmms-qpainterpath.patch
* Sun Mar 29 2020 Dave Plater <davejplater@gmail.com>
- Update to version 1.2.1 and enable wine dependent vst plugins in
  a seperate subpackage, see boo#1167345.
- Added tarballs for two VST specific 3rd party tarballs:
  rpmalloc b5bdc18051bb74a22f0bde4bcc90b01cf590b496.tar.gz
  and qt5-x11embed 022b39a1d496d72eb3e5b5188e5559f66afca957.tar.gz
- Added lmms-rpmalloc-fpic.patch
- Removed incorporated patches:
  0001-Better-French-translations-in-the-menu-item-file-471.patch
  0001-Fix-invalid-MIDI-Program-Change-decoding-5154.patch
  0001-show-BBEditor-on-clicking-the-TrackLabelButton-5060.patch
  0001-Make-splash-screen-text-white-5149.patch
  0001-Update-.mailmap-5037.patch
- Upstream changes:
  * Respect OS case sensitivity when check for existing files #4768
  * Remove MIDI connections from factory .mmpz files (#5163)
  * Make splash screen text white (#5149)
  * Show Beat/Bassline Editor on clicking track labels of B/B tracks
  (#5060)
  * Fix building RemoteVstPlugin with Wine >= 4.14 (#5210)
  * Fix stuck keys when dragging on the piano view (#5127)
  * Fix crash on unmarking octave semitones (#5184)
  * Fix invalid MIDI Program Change decoding (#5154)
  * Rubberband fix for selecting a large area in the song editor
  (#5003)
  * VeSTige: show icon on 'Turn off all notes' button (#5237)
  * RemoteVstPlugin: fix crashes when failed to open a file (#5235)
  * Organic: fix glitch at the beginning of a note (#5252)
  * Fix broken audio sample exporting on high sampling rate (#5226)
  * Better French translations in the menu item file (#4711)
  * Fix too long translations to fix the UI misalignment (#5185)
* Mon Sep  9 2019 Dave Plater <davejplater@gmail.com>
- Build vst plugins without wine to fix factory build.
- Build position independant executable.
- Added patches from git to fix issues after release:
  0001-Update-.mailmap-5037.patch
  0001-Better-French-translations-in-the-menu-item-file-471.patch
  0001-Fix-invalid-MIDI-Program-Change-decoding-5154.patch
  0001-Make-splash-screen-text-white-5149.patch
  0001-show-BBEditor-on-clicking-the-TrackLabelButton-5060.patch
* Mon Jun 17 2019 stephan.barth@suse.com
- rebased and renamed lmms-1.1.0-return.patch to lmms-1.2.0-return.patch
- removed lmms-fluidsynth.patch which is now integrated upstream
- Update to version 1.2.0:
  * fix color profile error (#5019)
  * DMG rebranding (#5013)
  * Fix German translation
  * Fixes #4996: Fix metadata when exporting multiple tracks (#5005)
  * updated splash (#5002)
  * MP3 export: initialize ID3 tag with id3tag_init
  * Travis: fix macOS build due to the old default version of Node.js
  * i18n: update template strings
  * Bugfix - SampleTrack -> Play: Fix sample track not being played in the right place when it not played from the begining.
  * Bugfix - SampleTrack -> Load & Save: Fix recorded sample track not being played correctly after saving and loading a project due to sample rate not getting saved in the project file.
  * SampleBuffer -> Use processingSampleRate.
  * i18n: update translations from Transifex
  * SampleTrack: call requestChangesInModel before unref SampleBuffer (#4982)
  * Fixes #4781: Don't disconnect LADSPA automation on export
  * Extend ProjectJournal docs, thx to @DomClark
  * Fix controller loading error on loading projects
  * Nescaline and Freeboy - Better default sound (#4968)
  * Fix race conditions in NotePlayHandleManager (#4966)
  * fix hanging mouse in piano roll (#4822) (#4960)
  * Fix invisible note editing handles when a note has detuning info
  * Use extracted linuxdeployqt directly
  * Don't draw note detuning info over the volume/panning area (#4965)
  * Travis: fix a debootstrap error from missing keyrings
  * Make more connections direct for automation (#4942)
  * Record chords (#4938)
  * Fix notes getting stuck under high CPU conditions (#4908)
  * Allow build for Wayland w/o X11Extras, if VST off
  * Use local cursor for TrackContentObjectView (#4918)
  * Allow sample track TCOs to resize smaller than one bar (#4933)
  * Don't try to connect to nonexistent controllers (#4939)
  * [Equalizer] Bright analyzer colors, opacity increased (#4772)
  * Travis: use carla instead of carla-git
  * Fix empty editors after closing them and creating a new project (#4891)
  * Allow new Zyn bank creation on Linux (#4905)
  * TCO drag: Fix Ctrl+Drag crash
  * Automation Editor: Don't accept drag events when there's no pattern
  * Fix Blackman-Harris window formula (#4895)
  * Fix layout of VstSyncData struct
  * Don't show error when loading empty VeSTige instance
  * Ensure VST windows show properly in taskbar
  * Add VST always-on-top config option
  * Avoid shallow clones in all Debian sid builds (#4888)
  * Fix compilation on Qt4
  * Fix zyn pitch on project load/export Closes #3451
  * Fix #3926: QCursor in AFP
  * Fix MidiJack crash on exit
  * Sync Debian version (#4840)
  * Blacklist $HOME as VST directory Closes #4854
  * Disable soundio on macOS
  * Fix AudioFileProcessor tooltip (#4868)
  * Add /sbin to AppImage search path Closes #4846
  * Fix DrumSynth sscanf (#4869)
  * Add missing include
  * Move apt_mingw_cache out of build directory (#4842)
  * Add needed macOS shortcuts (#4851)
  * Test deployment preparation in regular builds  (#4847)
  * lmms_math: Fix build with musl
  * Fix path to the LMMS binary in AppImage build script
  * Bump version to 1.2.0-rc8
  * AppImage: bundle JACK fallback library correctly
  * i18n: pull from Transifex
  * Bring back PortAudio support on Windows (#4770)
  * Fix Bitinvader waveform cutoff behavior
  * Ensure the restore button of a subwindow shows up correctly  (#4819)
  * Move QT_X11_NO_NATIVE_MENUBAR to code (#4818)
  * Fix Linux HiDPI handling
  * Follow instructions from cartr/homebrew-qt4 (#4815)
  * Don't let silent instruments wake up sleeping effects (#4792)
  * Fix CI by reverting rpmalloc
  * Disable built-in NaN handler through hidden setting (#4787)
  * Fixes #4752: Update rpmalloc
  * Fix address in doc/AUTHORS
  * Fixes #4778: Update mailmap
  * Increase forced clipping level
  * MIDI import/export: map note volume and MIDI velocity with their full range (#4785)
  * Pianoroll - Add checkpoint before moving notes
  * Improve handling of nan/inf (#4743)
  * Don't memcpy null pointer
  * Fix file extension list in translations
  * Link RemoteZynAddSubFx with -mwindows
  * Enable VST sync by default
  * Initialize peak controller last sample with base value fix (Stable 1.2) (#4699)
  * Do not depend on Git history, use data from 2019-01-07 (#4763)
  * Fix before_deploy (#4764)
  * Fix left 1px lfo graph
  * Fix builds on macOS Mojave 10.14 (#4767)
  * Fix infinite MIDI note with VST made in Cabbage (LMMS#4380) (#4766)
  * Keep off-grid position of TCOs on group moving (#4262)
  * Add source build artifact (#4744)
  * Don't render Automation tracks in the Beat/Bassline (#4747)
  * FX autoquit disabled by default (#4378)
  * Add Debian sid Clang build pass (#4735)
  * Fix broken FxLine tool tips (#3321)
  * Fix lost control links in copied automation patterns (#4723)
  * Add Debian sid i386 build pass (#4727)
  * Add Debian sid build pass (#4707)
  * Support more than 62 simultaneous VST plugins for Qt<5.10
  * Make ppqPos in VST sync sample accurate
  * Fix occasional Sinnah hang
  * Don't create MDI subwindow for VSTi without GUI
  * New pixmap as per #4519 (#4708)
  * Add initial Debian packaging for stable-1.2 (#4697)
  * Handle automation on processing thread (#4692)
  * Update TimeLineWidget 60 times per second (#4703)
  * Fix song editor visualization after maximizing (#4698)
  * Fix minor glitches with sample tracks (#4666)
  * Allow building SF2 player with FluidSynth 2.x (#4678)
  * Fix not saving some automations (#4632) (#4667)
  * Don't quit CLI rendering when failed to load sample files
  * Update name in mailmap
  * Fix german locale ('<Strg> + Mittelklick')
  * Fix unit tests for automation
  * Ensure correct TCOs after cloning tracks into the BB editor
  * Don't always treat empty long patterns as BB patterns
  * Fix VST track cloning in Beat/Bassline editor
  * Fix Carla detection in AppImage launcher script
* Sun Oct 28 2018 Edgar Aichinger <edogawa@aon.at>
- add lmms-fluidsynth.patch: backport upstream fix for fluidsynth API change
- remove lmms-1.2.0-undefined_ref.patch, already applied upstream in this release
- add lmms-1.2.0-libdir.patch: upstream patch to find plugin dir (use absolute paths in CMAKE_INSTALL_LIBDIR)
- change lmms-1.2.0-crippled_stk.patch to match current upstream source (tiny datatype change)
- install bash completions, by hand ATM until upstream finds a way to make DESTDIR work
* Thu Oct 25 2018 opensuse-packaging@opensuse.org
- Update to version 1.2.0rc7+git20180925.a2685c1cc:
  * Bump version to 1.2.0-rc7
  * Update the LMMS logo and mimetypes (#4519)
  * Add bash completion (#4534) (#4604)
  * Specify infinte timeout in tryLock on export
  * Update UI 60 times per second (#4570)
  * Add Carla support for MacOS (#4558)
  * Fallback to default audio/MIDI backends if invalid one is set
  * Validate audio/MIDI backend when opening setup dialog
  * Restructure help
  * Fix decimal separator handling (#4547)
  * Set VST program first when restoring settings
  * Initialise OLE in RemoteVstPlugin
  * Link RemoteVstPlugin with -mwindows
  * Fix VST windows resizing a little incorrectly
  * Fix kVstTransportChanged flag usage in VST sync
  * Fix hang when updateInOutCount called from processReplacing
  * Suspend plugin when changing sample rate/buffer size
  * Fix invisible editors on project load by validating size (#4502)
  * Allow building with sndio support on more systems than just OpenBSD (#4486)
  * Remove Qt temporary files after loading ZynAddSubFX settings (#4551)
  * Don't try to clear null buffer in NotePlayHandle::play (#4545)
  * Make the oscilloscope colors available as properties
  * Fix Freeboy noise channel playback (#4538)
  * Add CMake 2 support (#4530)
  * Fix AppImage shim launcher
  * Don't use dummy controllers for connections if not loading projects (#4493)
  * Fix some formatting issues in translations (#4482)
  * Setup Dialog - Fix bottom of letters cut off (#4483)
  * Fix broken MIDI import
  * Some demo project license fixes (#4481)
  * Use tryLock in audio threads for VST/ZynAddSubFX (#4460)
  * Always show sample track panning knobs (#4477)
  * Fix occasional audio interface deadlock (#4450)
  * Fix fwrite parameter ordering
  * Improve STK rawwave path encoding handling
  * Fix MIDI import encoding issue on Windows
  * Fix WAV exporting on Windows
  * Fix sample file loading on Windows
  * Fix file name encoding issues with ZynAddSubFX on Windows
  * Fix file name encoding issues with VST on Windows
  * Fix project URL for some files
  * Fix hang on exit from specific MIDI devices + WinMM (#4451)
  * CMake: Fix FindSndio module
  * CMake: Fix errors when path contains spaces
  * Quit exit if failing to save project (#4428)
  * LADSPA: Fix undefined reference due to vectorization (#4434)
  * Fixup 1bae047b98558981c20c85edc44550f4aa9714d9
  * Fix wrong accelerator character in sv.ts
  * Fix crash when loading project with missing peak controller effect (#4391)
  * Piano roll: reset editing mode when lost focus (#4393)
  * Piano roll: Fix some crashes when no pattern is open (#4392)
  * Deselect FX channel's name text when losing focus (#4293)
  * Initialize peak controller last sample with base value (#4382)
  * Fix automation processing priority
* Thu Oct 25 2018 Edgar Aichinger <edogawa@aon.at>
- update to version 1.2.0rc7
* Mon Aug 20 2018 mpluskal@suse.com
- Run spec-cleaner
- Simplify conditions
- Use cmake macros
- Drop unused dependencies
- Drop obsolete macros
- Adjust changelog to follow patch guidelines
- Fix changelog formatting
* Wed Aug 15 2018 edogawa@aon.at
- further cleanups and corrections in specfile:
  * BuildRequire just git-core, not git
  * rewrite BuildRequires: to use pkgconfig() for all the devel packages that support it
  * reenable use of %%{_smp_mflags} in make call
  * remove unneeded static library libqx11embedcontainer.a from package
  * comment out BuildRequires: to some 32bit devel packages for now (from an upstream list of build requirements)
- Drop not needed patches:
  * lmms-fix.patch
  * lmms-code-min.patch
  * lmms-code-macro.patch
  * lmms-carla.patch
  * lmms-code-indent.patch
  * lmms-1.1.3-fix-wrong-comparison-logic.patch
  * lmms-1.2.0-undefined_ref.patch
  * lmms-no-Werror.patch
* Sun Aug 12 2018 edogawa@aon.at
- update to 1.2.0rc6 using obs_scm source service, reworked patches and spec
  * rc6 release tarball misses some external submodule sources and doesn't compile, so use obs_scm
  * workaround the illegal "-" char in official version string (1.2.0-rc6)
  * modify/add BuildRequires to work for a Qt5 build
  * update and rename lmms-1.0.0-crippled_stk.patch to lmms-1.2.0-crippled_stk.patch
  * remove obsolete patches (applied upstream, problem fixed otherwise or pointing at now non-existing code)
  * build against Qt5
  * backport an upstream patch for upcoming rc7 to fix undefined references due to vectorization (gh#LMMS/lmms#4434)
* Fri Jul  6 2018 tiwai@suse.de
- Fix build error due to various false-positive gcc warnings:
  lmms-no-Werror.patch
* Thu Nov 30 2017 davejplater@gmail.com
- Fix Factory build failure with addition to lmms-carla.patch.
- Build position independent executables.
* Thu Aug 10 2017 olaf@aepfle.de
- ExclusiveArch x86_64 until carla-i386 is fixed
* Tue May 30 2017 meissner@suse.com
- lmms-fix.patch: Fixed potential 1 byte sprintf overflow. (bsc#1041293)
* Tue Mar 28 2017 olaf@aepfle.de
- ExclusiveArch Intel
* Thu Feb  9 2017 olaf@aepfle.de
- Build unconditionally with carla because it is in Tumbleweed
* Tue Oct 25 2016 stephan.barth@suse.com
- Added __requires_exclude_from to prevent RPM from adding a requirement for a
  library that only exists during build time (bsc#997249)
* Sat Jun 18 2016 olaf@aepfle.de
- Adjust indent to allow compile with gcc6 (bnc#985248)
  lmms-code-indent.patch
  lmms-code-macro.patch
  lmms-code-min.patch
* Thu Feb 25 2016 olaf@aepfle.de
- Use carla-standalone instead of Carla in pkgconfig
* Sat Jan 16 2016 edogawa@aon.at
- added support for internal Carla LV2/DSSI/VST plugin host
  * lmms-carla.patch: backported an upstream patch to implement NATIVE_HOST_OPCODE_HOST_IDLE
  * added falkTX's fix for lib/lib64 in the hardcoded carla plugin resource path so that they will find their GUIs
* Fri Jul  3 2015 olaf@aepfle.de
- Add versioned BuildRequires, adjust wine BuildRequires
* Wed Jun 24 2015 antoine.belvire@laposte.net
- Fix compilation with GCC 5:
  * Add lmms-1.1.3-fix-wrong-comparison-logic.patch from upstream.
  * Add fgnu89-inline to CFLAGS.
* Fri Mar 27 2015 stephan.barth@suse.com
- Reverted Source0 tag to the real download location
* Mon Mar  9 2015 stephan.barth@suse.com
- Update to version 1.1.3 from 1.1.0
  Upstream changes:
  - Fix pops and clicks introduced with new mixer (Bug #1662)
  - Fix 0%% export bug affecting certain languages/locales (Bug #1496)
  - Fix Watsyn shows wrong selection after switching instruments (Bug #1526)
  - Fix Nescaline crash when playing very high notes (Bug #1492)
  - Fix AudioFileProcessor wave display bug (Bug #929)
  - Fix various memory leaks
* Sun Feb 15 2015 devel.suse@gmail.com
- Change URL project link and some spec file changes
* Sat Feb 14 2015 reddwarf@opensuse.org
- Use real 1.1.0 tarball
  The previous commit used a random git commit, even if it said 1.1.0
- Revert back to lmms-1.0.0-crippled_stk.patch
- Remove precheckin_cripple_tarball.sh and related
  The real 1.1.0 tarball doesn't contain the problematic file anymore
- Update the Source tag with the new download URL
- lmms-1.1.0-return.patch keeps substituting lmms-1.0.0-return.patch
  Just to make the factory-auto script happy
* Fri Dec 26 2014 stephan.barth@suse.com
- Rebased crippled_stk.patch
  lmms-1.1.0-crippled_stk.patch
- Added more output to precheckin_cripple_tarball.sh
- Fixed lmms-1.1.0-return.patch. Only file location changed.
- Update to version 1.1.0
  Most interesting upstream changes:
  * New FX Mixer
  * New Instruments:
    + Nescaline - Nintendo Entertainment System(R) sound emulator
    + Watsyn - Advanced wavetable synth
    + Monstro - Advanced triple oscillator synth
    + Carla - Audio plugin host (Linux only)
  * Instrument Enhancements:
    + AudioFileProcessor - Adjustable loop points
    + Kicker - Temposyncable envelope, higher max; distortion enhancements
    + LB302 - Fix note sticking, playback bugs
  * UI Improvements
    + Piano Roll:
    Ctrl + Left/Right Arrow keys now moves selected notes by one bar
    Shift + Up/Down now moves selected notes by one semitone
  * Enabled toggling of knob scale in context menu (Linear/Logarithmic)
  * Added ability to record automations
  * Added support for undo/redo in Piano Roll
  * Bug Fixes
* Sat Aug  2 2014 stephan.barth@suse.com
- upgrade to version 1.0.3 from 1.0.2
  Relevant upstream changes:
  - Fix SF2 note volume
  - Localization updates
  - Updated LADSPA search paths
  - Bugfixes in plugins
* Mon Jun  2 2014 stephan.barth@suse.com
- reinstated full bcond if condition and added upstream URL back
- removed BuildRequires for portaudio-devel and sdl, because they are not
  needed.
* Fri May  9 2014 stephan.barth@suse.com
- update to version 1.0.2 which is bugfix release
* Fri May  2 2014 stephan.barth@suse.com
- update to version 1.0.0
- Added BuildRequires for wine to be still able to build the VST plugin
- Added explicit Requires for %%{_bindir}/wineserver which is needed for full
  VST support
- removed patches:
  - lmms-0.4.14-system_fltk.patch
    lmms now uses system fltk by itself
- redone patches:
  - lmms-1.0.0-crippled_stk.patch
  - lmms-1.0.0-return.patch
- added Requires for portaudio-devel and pkgconfig(sdl)
- updated precheckin_cripple_tarball.sh since the tarball name slightly
  changed
* Thu Aug  1 2013 reddwarf@opensuse.org
- Enable VST support in openSUSE 12.3 x86-64
* Wed Jun 12 2013 reddwarf@opensuse.org
- Update to 0.4.15
  * AutomationPattern: initialize with current value of first object
  * Chords: fixed major pentatonic
  * Properly cancel file export if opening output file failed
  * InstrumentTrack: fix freeze when forwarding MIDI events to instrument
  * Sf2Player: preserve custom track name when loading settings
  * AudioFileProcessor: make playback cursor configurable
  * AudioFileProcessor: fix crash with reversed samples
* Wed May  1 2013 reddwarf@opensuse.org
- Add lmms-0.4.14-system_fltk.patch.
- Stop building the portaudio and sdl audio backends. There is no
  need for wrappers when the real backends are directly supported.
- Remove one %%if. wine-32bit has never been a substitute for wine-devel-32bit.
- Use %%{_defaultdocdir} instead of {_datadir}/doc/packages
* Mon Apr 29 2013 stephan.barth@suse.com
- update to version 0.4.14 which is a maintainance release "with some exciting
  new features (notably regarding VST support)"
  Full upstream changelog can be found in
  /usr/share/doc/packages/lmms/releasenotes-0.4.14.txt
- removed the following patches because they have been applied upstream:
  - lmms-0.4.12-overflow.patch
  - lmms-0.4.13-gcc47.patch
- removed lmms-0.4.12-system_fltk.patch because the UI now fails to link with
  "undefined references" with the openSUSE fltk. Package now builds with fltk
  provided by its own tarball
* Tue Sep 11 2012 reddwarf@opensuse.org
- Recommend %%{_bindir}/wine, needed by the VST plugin
- Don't remove execute permission from VST and ZynAddSubFx plugins
- Don't remove rpath, it's needed by the ZynAddSubFx plugin
* Wed Aug 22 2012 dmueller@suse.com
- simply set libdir in the cmake call, which fixes build for ARM
* Mon Aug  6 2012 dvaleev@suse.com
- set libdir on powerpc correctly
* Wed May 16 2012 reddwarf@opensuse.org
- Fix build with openSUSE's crippled stk
* Tue May  8 2012 reddwarf@opensuse.org
- Add precheckin_cripple_tarball.sh logic (bnc#761147)
* Fri Apr 27 2012 reddwarf@opensuse.org
- Remove %%suse_update_desktop_file usage
- Add lmms-0.4.13-gcc47.patch
* Thu Mar  8 2012 reddwarf@opensuse.org
- Initial package
